@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Corentin Chary <corentin.chary@gmail.com>
+ * Copyright (C) 2010-2011 Corentin Chary <corentin.chary@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,13 +17,17 @@
  */
 
 #include "mapwidget_lite.h"
+#include "station.h"
 
 MapWidget::MapWidget(QWidget * parent)
   : QLabel(parent)
 {
 #if defined(Q_WS_S60) || defined(Q_WS_SIMULATOR)
-  setText(tr("The Map functionality is not supported in the lite version,"
-	     "you need to purchase the full version on OVI store."));
+  setWordWrap(true);
+  setText(tr("Map functionality is not available in the lite version,"
+	     " you need to purchase the full version on "
+		 "<a href='http://store.ovi.com/content/65625'>OVI store</a>."));
+  setOpenExternalLinks(true);
 #else
   setText(tr("Map not supported."));
 #endif
@@ -52,9 +56,10 @@ MapWidget::centerView(const QPointF & position, int zoom)
   Q_UNUSED(zoom);
 }
 
+#ifdef HAVE_QT_LOCATION
 void
 MapWidget::positionUpdated(const QGeoPositionInfo & info)
 {
   Q_UNUSED(info);
 }
-
+#endif
