@@ -70,6 +70,8 @@ SettingsDialog::SettingsDialog(QWidget *parent)
 #if !defined(HAVE_QT_LOCATION)
   ui->checkBox->hide();
 #endif
+
+  connect(ui->clearCacheButton, SIGNAL(clicked()), this, SLOT(clearCache()));
 }
 
 SettingsDialog::~SettingsDialog()
@@ -87,3 +89,11 @@ SettingsDialog::saveSettings() const
   conf.setValue("MapProvider", provider);
   conf.setValue("GpsPowerSave", ui->checkBox->checkState() == Qt::Checked);
 }
+
+void
+SettingsDialog::clearCache()
+{
+  ui->clearCacheButton->setDisabled(true);
+  Settings::clearCache();
+  ui->clearCacheButton->setEnabled(true);
+}
