@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Corentin Chary <corentin.chary@gmail.com>
+ * Copyright (C) 2010-2011 Corentin Chary <corentin.chary@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@ StationDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
 		       const QModelIndex &index) const
 {
   Station *station = (Station *)index.data(StationsModel::StationRole).value<void *>();
+  QString description, name;
 
   if (!station)
     return QStyledItemDelegate::paint(painter, option, index);
@@ -76,7 +77,17 @@ StationDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
   rect.setTop(rect.top() + 5);
 
   painter->setFont(font);
-  painter->drawText(rect, Qt::AlignLeft|Qt::AlignTop, station->name());
+  name = station->name();
+  if (QFontMetrics(font).width(name) > option.rect.width()) {
+      QFontMetrics fm(font);
+      qreal size = qMax(0, option.rect.width());
+
+      size /= fm.averageCharWidth();
+      size -= QString::fromLatin1(" ... ").size();
+      name = station->name().left(size);
+      name += QLatin1String("...");
+  }
+  painter->drawText(rect, Qt::AlignLeft|Qt::AlignTop, name);
 
   if (index.data(StationsModel::StationBookmarkRole).toBool()) {
     QPixmap bookmark = QPixmap(":/res/favorites.png").scaled(16, 16, Qt::KeepAspectRatio, Qt::SmoothTransformation);
@@ -93,16 +104,21 @@ StationDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
 #endif
   painter->setFont(font);
 
-  QString description;
   qreal distance = index.data(StationsSortFilterProxyModel::StationDistanceRole).toDouble();
   QString distanceText;
 
-#if !defined(Q_WS_S60) && !defined(Q_WS_SIMULATOR)
-  if (distance >= 0)
-    distanceText.sprintf(" (%dm)", (int)distance);
-
+  if (distance >= 0) {
+      if (distance >= 1000) {
+          distanceText.sprintf("%.1fkm", distance / 1000.);
+      } else {
+          distanceText.sprintf("%dm", (int)distance);
+      }
+  }
+#if defined(Q_WS_S60) || defined(Q_WS_SIMULATOR)
+  painter->drawText(rect, Qt::AlignLeft|Qt::AlignBottom, distanceText);
+#else
   description = station->description();
-  description += distanceText;
+  description += " (" + distanceText + ")";
   if (QFontMetrics(font).width(description) > option.rect.width()) {
       QFontMetrics fm(font);
       qreal size = qMax(0, option.rect.width() - fm.width(distanceText));
