@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Corentin Chary <corentin.chary@gmail.com>
+ * Copyright (C) 2010-2011 Corentin Chary <corentin.chary@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 #include "stationspluginfactorysimple.h"
 
-class StationsPluginFactoryLatvia : public QObject, public StationsPluginFactorySimple
+class StationsPluginFactoryLatvia : public StationsPluginFactorySimple
 {
   Q_OBJECT
   Q_INTERFACES(StationsPluginFactory)
